    .. _upnp_services_servers_scheduled_recording_server:

coherence.upnp.services.servers.scheduled\_recording\_server (module)
---------------------------------------------------------------------

.. automodule:: coherence.upnp.services.servers.scheduled_recording_server
